@@ -1,4 +1,4 @@
-# Copyright 2001-2010, Paul Johnson (pjcj@cpan.org)
+# Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,19 +10,19 @@ package Devel::Cover::Criterion;
 use strict;
 use warnings;
 
-our $VERSION = "0.73";
+our $VERSION = '0.89'; # VERSION
 
-use Devel::Cover::Statement       0.73;
-use Devel::Cover::Branch          0.73;
-use Devel::Cover::Condition       0.73;
-use Devel::Cover::Condition_or_2  0.73;
-use Devel::Cover::Condition_or_3  0.73;
-use Devel::Cover::Condition_and_2 0.73;
-use Devel::Cover::Condition_and_3 0.73;
-use Devel::Cover::Condition_xor_4 0.73;
-use Devel::Cover::Subroutine      0.73;
-use Devel::Cover::Time            0.73;
-use Devel::Cover::Pod             0.73;
+use Devel::Cover::Statement;
+use Devel::Cover::Branch;
+use Devel::Cover::Condition;
+use Devel::Cover::Condition_or_2;
+use Devel::Cover::Condition_or_3;
+use Devel::Cover::Condition_and_2;
+use Devel::Cover::Condition_and_3;
+use Devel::Cover::Condition_xor_4;
+use Devel::Cover::Subroutine;
+use Devel::Cover::Time;
+use Devel::Cover::Pod;
 
 sub coverage    { $_[0][0] }
 sub information { $_[0][1] }
@@ -75,6 +75,10 @@ __END__
 
 Devel::Cover::Criterion - Code coverage metrics for Perl
 
+=head1 VERSION
+
+version 0.89
+
 =head1 SYNOPSIS
 
  use Devel::Cover::Criterion;
@@ -95,13 +99,9 @@ Abstract base class for all the coverage criteria.
 
 Huh?
 
-=head1 VERSION
-
-Version 0.73 - 2nd October 2010
-
 =head1 LICENCE
 
-Copyright 2001-2010, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
