@@ -1,4 +1,4 @@
-# Copyright 2001-2006, Paul Johnson (pjcj@cpan.org)
+# Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -12,7 +12,9 @@ require 5.8.0;  # My patches to B::Concise didn't get released till 5.8.0.
 use strict;
 use warnings;
 
-our $VERSION = "0.59";
+our $VERSION = '0.89'; # VERSION
+
+use Devel::Cover::Dumper;
 
 use Devel::Cover qw( -ignore blib -ignore \\wB\\w );
 use B::Concise   qw( set_style add_callback );
@@ -24,7 +26,7 @@ my %style =
     "(*(    )*)goto #class (#addr)\n",
     "#class pp_#name"],
    "concise" =>
-   ["#hyphseq2 #cover12 (*(   (x( ;)x))*)<#classsym> "
+   ["#hyphseq2 #addr10 #cover12 (*(   (x( ;)x))*)<#classsym> "
     . "#exname#arg(?([#targarglife])?)~#flags(?(/#private)?)(x(;~->#next)x)\n",
     "  (*(    )*)     goto #seq\n",
     "(?(<#seq>)?)#exname#arg(?([#targarglife])?)"],
@@ -58,7 +60,6 @@ sub import
         {
             my ($h, $op, $format, $level) = @_;
             my $key = Devel::Cover::get_key($op);
-            # use Data::Dumper; $Data::Dumper::Indent = 1;
             # print Dumper Devel::Cover::coverage unless $d++;
             if ($h->{seq})
             {
@@ -90,6 +91,10 @@ __END__
 
 Devel::Cover::Op - B::Concise with coverage data
 
+=head1 VERSION
+
+version 0.89
+
 =head1 SYNOPSIS
 
  perl -Mblib -MDevel::Cover::Op prog [options]
@@ -97,7 +102,7 @@ Devel::Cover::Op - B::Concise with coverage data
 =head1 DESCRIPTION
 
 This module works as if calling B::Concise but also outputs coverage
-information.  It's primary purpose is to aid in the development of Devel::Cover.
+information.  Its primary purpose is to aid in the development of Devel::Cover.
 
 See comments in Cover.xs (especially set_conditional()) to aid in interpreting
 the output.
@@ -110,13 +115,9 @@ the output.
 
 Huh?
 
-=head1 VERSION
-
-Version 0.59 - 23rd August 2006
-
 =head1 LICENCE
 
-Copyright 2001-2006, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
