@@ -1,4 +1,4 @@
-# Copyright 2001-2011, Paul Johnson (pjcj@cpan.org)
+# Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -18,9 +18,9 @@ package Devel::Cover::Report::Compilation;
 use strict;
 use warnings;
 
-our $VERSION = "0.77";
+our $VERSION = '0.89'; # VERSION
 
-use Devel::Cover::DB 0.77;
+use Devel::Cover::DB;
 
 # TODO - uncoverable code?
 
@@ -143,6 +143,10 @@ __END__
 
 =head1 NAME
 
+
+=head1 VERSION
+
+version 0.89
 Devel::Cover::Report::Compilation - Backend for reporting of coverage
 statistics in a format like Perl compilation
 
@@ -167,13 +171,9 @@ through the reports.
 
 Huh?
 
-=head1 VERSION
-
-Version 0.77 - 15th May 2011
-
 =head1 LICENCE
 
-Copyright 2001-2011, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
