@@ -1,4 +1,4 @@
-# Copyright 2001-2011, Paul Johnson (pjcj@cpan.org)
+# Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,10 +10,12 @@ package Devel::Cover::Report::Html_basic;
 use strict;
 use warnings;
 
-our $VERSION = "0.77";
+our $VERSION = '0.89'; # VERSION
+our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
-use Devel::Cover::DB 0.77;
-use Devel::Cover::Web 0.77 "write_file";
+use Devel::Cover::DB;
+use Devel::Cover::Html_Common "launch";
+use Devel::Cover::Web "write_file";
 
 use Getopt::Long;
 use Template 2.00;
@@ -38,15 +40,17 @@ sub oclass
     $o ? class($o->percentage, $o->error, $criterion) : ""
 }
 
+my $threshold = { c0 => 75, c1 => 90, c2 => 100 };
+
 sub class
 {
     my ($pc, $err, $criterion) = @_;
     return "" if $criterion eq "time";
     no warnings "uninitialized";
     !$err ? "c3"
-          : $pc <  75 ? "c0"
-          : $pc <  90 ? "c1"
-          : $pc < 100 ? "c2"
+          : $pc < $threshold->{c0} ? "c0"
+          : $pc < $threshold->{c1} ? "c1"
+          : $pc < $threshold->{c2} ? "c2"
           : "c3"
 }
 
@@ -132,9 +136,9 @@ sub _highlight_perltidy {
     my @coloured = ();
 
     Perl::Tidy::perltidy(
-        source      => \@all_lines, 
-        destination => \@coloured, 
-        argv        => '-html -pre -nopod2html', 
+        source      => \@all_lines,
+        destination => \@coloured,
+        argv        => '-html -pre -nopod2html',
         stderr      => '-',
         errorfile   => '-',
     );
@@ -233,8 +237,7 @@ sub print_file
         lines => \@lines,
     };
 
-    my $html = "$R{options}{outputdir}/$R{filenames}{$R{file}}.html";
-    $Template->process("file", $vars, $html) or die $Template->error();
+    $Template->process("file", $vars, $R{file_html}) or die $Template->error();
 }
 
 sub print_branches
@@ -322,7 +325,7 @@ sub print_conditions
         types => \@types,
     };
 
-    # use Data::Dumper; print Dumper \@types;
+    # use Devel::Cover::Dumper; print Dumper \@types;
 
     my $html = "$R{options}{outputdir}/$R{filenames}{$R{file}}--condition.html";
     $Template->process("conditions", $vars, $html) or die $Template->error();
@@ -376,6 +379,8 @@ sub get_options
 {
     my ($self, $opt) = @_;
     $opt->{option}{outputfile} = "coverage.html";
+    $threshold->{$_} = $opt->{"report_$_"} for
+        grep { defined $opt->{"report_$_"} } qw( c0 c1 c2 );
     die "Invalid command line options" unless
         GetOptions($opt->{option},
                    qw(
@@ -405,6 +410,7 @@ sub report
                     $year + 1900, $mon + 1, $mday, $hour, $min, $sec
         },
         options => $options,
+        version => $LVERSION,
         showing => [ grep $options->{show}{$_}, $db->criteria ],
         headers =>
         [
@@ -432,6 +438,7 @@ sub report
     for (@{$options->{file}})
     {
         $R{file} = $_;
+        $R{file_html} = "$options->{outputdir}/$R{filenames}{$_}.html";
         my $show = $options->{show};
         print_file;
         print_branches    if $show->{branch};
@@ -439,7 +446,7 @@ sub report
         print_subroutines if $show->{subroutine} || $show->{pod};
     }
 
-    print "HTML output sent to $html\n";
+    print "HTML output written to $html\n" unless $options->{silent};
 }
 
 1;
@@ -449,7 +456,7 @@ package Devel::Cover::Report::Html_basic::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = "0.77";
+our $VERSION = '0.89'; # VERSION
 
 use base "Template::Provider";
 
@@ -469,8 +476,8 @@ $Templates{html} = <<'EOT';
      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <!--
-This file was generated by Devel::Cover Version 0.77
-Devel::Cover is copyright 2001-2011, Paul Johnson (pjcj@cpan.org)
+This file was generated by Devel::Cover Version [% version %]
+Devel::Cover is copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
@@ -534,6 +541,22 @@ $Templates{summary} = <<'EOT';
         <td class="sh" align="right">Report date:</td>
         <td class="sv" align="left">[% R.date %]</td>
     </tr>
+    <tr>
+        <td class="sh" align="right">C0:</td>
+        <td class="sv c0" align="left">&lt;&nbsp;[% R.options.report_c0 %]%</td>
+    </tr>
+    <tr>
+        <td class="sh" align="right">C1:</td>
+        <td class="sv c1" align="left">&lt;&nbsp;[% R.options.report_c1 %]%</td>
+    </tr>
+    <tr>
+        <td class="sh" align="right">C2:</td>
+        <td class="sv c2" align="left">&lt;&nbsp;[% R.options.report_c2 %]%</td>
+    </tr>
+    <tr>
+        <td class="sh" align="right">C3:</td>
+        <td class="sv c3" align="left">&gt;=&nbsp;[% R.options.report_c2 %]%</td>
+    </tr>
 </table>
 <div><br></br></div>
 <table class="sortable" id="coverage_table">
@@ -651,7 +674,9 @@ $Templates{branches} = <<'EOT';
     [% FOREACH branch = branches %]
         <a name="[% branch.ref %]"> </a>
         <tr>
-            <td class="h"> [% branch.number %] </td>
+            <td class="h">
+                <a href="[% R.file_html %]#[% branch.number %]">[% branch.number %]</a>
+            </td>
             [% FOREACH part = branch.parts %]
                 <td class="[% part.class %]"> [% part.text %] </td>
             [% END %]
@@ -685,7 +710,9 @@ $Templates{conditions} = <<'EOT';
         [% FOREACH condition = type.conditions %]
             <a name="[% condition.ref %]"> </a>
             <tr>
-                <td class="h"> [% condition.number %] </td>
+                <td class="h">
+                    <a href="[% R.file_html %]#[% condition.number %]">[% condition.number %]</a>
+                </td>
                 [% FOREACH part = condition.parts %]
                     <td class="[% part.class %]"> [% part.text %] </td>
                 [% END %]
@@ -723,7 +750,9 @@ $Templates{subroutines} = <<'EOT';
     </tr>
     [% FOREACH sub = subs %]
         <tr>
-            <td class="h"> [% sub.line %] </td>
+            <td class="h">
+                <a href="[% R.file_html %]#[% sub.line %]">[% sub.line %]</a>
+            </td>
             [% IF R.options.show.subroutine %]
                 <td class="[% sub.class %]"> [% sub.count %] </td>
             [% END %]
@@ -745,14 +774,16 @@ s/^\s+//gm for values %Templates;
 
 =head1 NAME
 
+
+=head1 VERSION
+
+version 0.89
 Devel::Cover::Report::Html_basic - Backend for HTML reporting of coverage
 statistics
 
 =head1 SYNOPSIS
 
- use Devel::Cover::Report::Html_basic;
-
- Devel::Cover::Report::Html_basic->report($db, $options);
+ cover -report html_basic
 
 =head1 DESCRIPTION
 
@@ -768,13 +799,9 @@ highlighting if C<PPI::HTML> or C<Perl::Tidy> is installed.
 
 Huh?
 
-=head1 VERSION
-
-Version 0.77 - 15th May 2011
-
 =head1 LICENCE
 
-Copyright 2001-2011, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
