@@ -4,15 +4,17 @@ use strict;
 use warnings;
 use CGI;
 use Getopt::Long;
-use Devel::Cover::DB 0.73;
-use Devel::Cover::Truth_Table 0.73;
+use Devel::Cover::DB;
+use Devel::Cover::Html_Common "launch";
+use Devel::Cover::Truth_Table;
 
-our $VERSION = "0.73";
+our $VERSION = '0.89'; # VERSION
+our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_coverage_for_line
 # Purpose    : Retreive all available data for requested metrics on a line.
-# Notes      : 
+# Notes      :
 #-------------------------------------------------------------------------------
 sub get_coverage_for_line {
     my ($options, $data, $line) = @_;
@@ -27,8 +29,8 @@ sub get_coverage_for_line {
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_summary_for_file
-# Purpose    : 
-# Notes      : 
+# Purpose    :
+# Notes      :
 #-------------------------------------------------------------------------------
 sub get_summary_for_file {
     my $db   = shift;
@@ -56,8 +58,8 @@ sub get_summary_for_file {
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_showing_headers
-# Purpose    : 
-# Notes      : 
+# Purpose    :
+# Notes      :
 #-------------------------------------------------------------------------------
 sub get_showing_headers {
     my $db      = shift;
@@ -76,8 +78,8 @@ sub get_showing_headers {
 
 #-------------------------------------------------------------------------------
 # Subroutine : truth_table
-# Purpose    : 
-# Notes      : 
+# Purpose    :
+# Notes      :
 #-------------------------------------------------------------------------------
 sub truth_table {
     return if @_ > 16;
@@ -150,6 +152,7 @@ sub merge_lineops {
 #===============================================================================
 my %Filenames;
 my @class = qw'c0 c1 c2 c3';
+my $threshold = { c0 => 75, c1 => 90, c2 => 100 };
 
 #-------------------------------------------------------------------------------
 # Subroutine : bclass()
@@ -169,16 +172,16 @@ sub bclass {
 sub pclass {
     my ($p, $e) = @_;
     return $class[3] unless $e;
-    $p <  75 && return $class[0];
-    $p <  90 && return $class[1];
-    $p < 100 && return $class[2];
+    $p < $threshold->{c0} && return $class[0];
+    $p < $threshold->{c1} && return $class[1];
+    $p < $threshold->{c2} && return $class[2];
     $class[3]
 }
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_coverage_report
-# Purpose    : 
-# Notes      : 
+# Purpose    :
+# Notes      :
 #-------------------------------------------------------------------------------
 sub get_coverage_report {
     my $type = shift;
@@ -212,7 +215,7 @@ sub _branch_report {
 #-------------------------------------------------------------------------------
 sub _condition_report {
     my $coverage = shift;
-    # use Data::Dumper; print STDERR Dumper $coverage;
+    # use Devel::Cover::Dumper; print STDERR Dumper $coverage;
 
     my @tables = truth_table(@{$coverage->{condition}});
     return unless @tables;
@@ -261,8 +264,8 @@ sub print_html_header {
      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <!--
-This file was generated by Devel::Cover Version 0.73
-Devel::Cover is copyright 2001-2010, Paul Johnson (pjcj\@cpan.org)
+This file was generated by Devel::Cover Version $LVERSION
+Devel::Cover is copyright 2001-2012, Paul Johnson (paul\@pjcj.net)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
@@ -281,8 +284,8 @@ END_HTML
 
 #-------------------------------------------------------------------------------
 # Subroutine : print_summary
-# Purpose    : 
-# Notes      : 
+# Purpose    :
+# Notes      :
 #-------------------------------------------------------------------------------
 sub print_summary {
     my $fh       = shift;
@@ -310,8 +313,8 @@ END_HTML
 
 #-------------------------------------------------------------------------------
 # Subroutine : print_th
-# Purpose    : 
-# Notes      : 
+# Purpose    :
+# Notes      :
 #-------------------------------------------------------------------------------
 sub print_th {
     my ($fh, $th, $span) = @_;
@@ -325,8 +328,8 @@ sub print_th {
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_link
-# Purpose    : 
-# Notes      : 
+# Purpose    :
+# Notes      :
 #-------------------------------------------------------------------------------
 sub get_link {
     my $file = shift;
@@ -351,8 +354,6 @@ sub print_summary_report {
 
     my $outfile = "$options->{outputdir}/$options->{option}{outputfile}";
 
-    print "Writing HTML output to $outfile ...\n" unless $options->{silent};
-
     open(my $fh, '>', $outfile)
         or warn("Unable to open file '$outfile' [$!]\n"), return;
 
@@ -360,11 +361,26 @@ sub print_summary_report {
     push @$show, 'total';
 
     print_html_header($fh, $options->{option}{summarytitle});
+    # TODO - >= 100% doesn't look nice.  See also Html_basic.
     print $fh <<"END_HTML";
 <body>
 <h1>$options->{option}{summarytitle}</h1>
 <table>
-<tr><td class="h" align="right">Database:</td><td align="left">$db->{db}</td></tr>
+  <tr>
+    <td class="h" align="right">Database:</td><td align="left">$db->{db}</td>
+  </tr>
+  <tr>
+    <td class="h" align="right">C0:</td><td class="c0" align="left">&lt;&nbsp;$options->{report_c0}\%</td>
+  </tr>
+  <tr>
+    <td class="h" align="right">C1:</td><td class="c1" align="left">&lt;&nbsp;$options->{report_c1}\%</td>
+  </tr>
+  <tr>
+    <td class="h" align="right">C2:</td><td class="c2" align="left">&lt;&nbsp;$options->{report_c2}\%</td>
+  </tr>
+  <tr>
+    <td class="h" align="right">C3:</td><td class="c3" align="left">&gt;=&nbsp;$options->{report_c2}\%</td>
+  </tr>
 </table>
 <div><br/></div>
 <table>
@@ -412,13 +428,16 @@ END_HTML
     }
     print $fh "</table>\n</body>\n</html>\n";
     close($fh) or warn "Unable to close '$outfile' [$!]";
+
+    print "HTML output written to $outfile\n" unless $options->{silent};
+
 }
 
 
 #-------------------------------------------------------------------------------
 # Subroutine : escape_HTML
 # Purpose    : make source code web-safe
-# Notes      : 
+# Notes      :
 #-------------------------------------------------------------------------------
 sub escape_HTML {
     my $text = shift;
@@ -521,7 +540,7 @@ sub print_file_report {
                     if ($c =~ /branch|condition|subroutine/) {
                         $link = get_link($fin, $c, $.);
                     }
-    
+
                     no warnings "uninitialized";  # TODO - hack, get rid of this
                     my $text = '<div';
                     $text .= $m->{class} ? qq' class="$m->{class}"' : '';
@@ -631,8 +650,8 @@ sub print_condition_report {
 
 #-------------------------------------------------------------------------------
 # Subroutine : print_sub_report
-# Purpose    : 
-# Notes      : 
+# Purpose    :
+# Notes      :
 #-------------------------------------------------------------------------------
 sub print_sub_report {
     my ($db, $file, $opt) = @_;
@@ -674,6 +693,8 @@ sub get_options
     $opt->{option}{pod}          = 1;
     $opt->{option}{outputfile}   = "coverage.html";
     $opt->{option}{summarytitle} = "Coverage Summary";
+    $threshold->{$_} = $opt->{"report_$_"} for
+        grep { defined $opt->{"report_$_"} } qw( c0 c1 c2 );
     die "Invalid command line options" unless
         GetOptions($opt->{option},
                    qw(
@@ -682,6 +703,9 @@ sub get_options
                        pod!
                        summarytitle=s
                        unified!
+                       report_c0=s
+                       report_c1=s
+                       report_c2=s
                      ));
 }
 
@@ -715,14 +739,16 @@ sub report {
 
 =head1 NAME
 
+
+=head1 VERSION
+
+version 0.89
 Devel::Cover::Report::Html_minimal - Backend for HTML reporting of coverage
 statistics
 
 =head1 SYNOPSIS
 
- use Devel::Cover::Report::Html_minimal;
-
- Devel::Cover::Report::Html_minimal->report($db, $options);
+ cover -report html_minimal
 
 =head1 DESCRIPTION
 
@@ -747,26 +773,26 @@ directory.
 
 =item pod
 
-Includes POD (and blank lines) in the file report. This is on by default.  It
+Includes POD (and blank lines) in the file report.  This is on by default.  It
 may be turned off with -nopod.
 
 =item data
 
-Includes text after the C<__DATA__> or C<__END__> tokens in the file report. By
+Includes text after the C<__DATA__> or C<__END__> tokens in the file report.  By
 default, this text is trimmed.
 
 Note: If your POD is after an C<__END__>, you have to specify 'data' to include
-it, not 'pod'. The 'pod' option only applies to POD before the C<__END__>.
+it, not 'pod'.  The 'pod' option only applies to POD before the C<__END__>.
 
 =item unified
 
-Generates a "unified" report for each file. The detailed data that normally
-appears in the auxilliary reports (branch, condition, etc.) is placed in the
-file report, and the auxilliarry reports are not generated.
+Generates a "unified" report for each file.  The detailed data that normally
+appears in the auxiliary reports (branch, condition, etc.) are placed in the
+file report, and the auxiliary reports are not generated.
 
 =item summarytitle
 
-Specify the tile of the summary.  The default is "Coverage Summary".
+Specify the title of the summary.  The default is "Coverage Summary".
 
 =back
 
@@ -774,13 +800,9 @@ Specify the tile of the summary.  The default is "Coverage Summary".
 
 Devel::Cover
 
-=head1 VERSION
-
-Version 0.73 - 2nd October 2010
-
 =head1 LICENCE
 
-Copyright 2001-2010, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 This software is free. It is licensed under the same terms as Perl itself.
 
