@@ -2,9 +2,9 @@ package Devel::Cover::Report::Text2;
 use strict;
 use warnings;
 
-our $VERSION = "0.73";
+our $VERSION = '0.89'; # VERSION
 
-use Devel::Cover::DB 0.73;
+use Devel::Cover::DB;
 use Devel::Cover::Truth_Table;
 
 my %format = (
@@ -167,14 +167,16 @@ __END__
 
 =head1 NAME
 
-Devel::Cover::Report::Text - Backend for textual reporting of coverage
+
+=head1 VERSION
+
+version 0.89
+Devel::Cover::Report::Test2 - Backend for textual reporting of coverage
 statistics
 
 =head1 SYNOPSIS
 
- use Devel::Cover::Report::Text;
-
- Devel::Cover::Report::Text->report($db, $options);
+ cover -report text2
 
 =head1 DESCRIPTION
 
@@ -189,13 +191,9 @@ It is designed to be called from the C<cover> program.
 
 Huh?
 
-=head1 VERSION
-
-Version 0.73 - 2nd October 2010
-
 =head1 LICENCE
 
-Copyright 2001-2010, Paul Johnson (pjcj@cpan.org)
+Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -203,4 +201,3 @@ The latest version of this software should be available from my homepage:
 http://www.pjcj.net
 
 =cut
-
